| Title: | View Images on Full Screen in 'RMarkdown' Documents and 'shiny' Applications |
|---|---|
| Description: | Allows the user to view an image in full screen when clicking on it in 'RMarkdown' documents and 'shiny' applications. The package relies on the 'JavaScript' library 'intense-images'. See <https://tholman.com/intense-images/> for more information. |
| Authors: | Mohamed El Fodil Ihaddaden [aut, cre], Tim Holman [ctb, cph] (intense-images.js library developer) |
| Maintainer: | Mohamed El Fodil Ihaddaden <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-12 05:39:25 UTC |
| Source: | https://github.com/feddelegrand7/rintimg |
Viewing images on full screen
img_intensify(target = "img")img_intensify(target = "img")
target |
By default, the function intensifies all the images (<img> tag) however the user can target specific classes |
images that when clicked can be viewed on full screen no matter their initial size
if (interactive()) { ui <- fluidPage( h1("Click on the image to view it in full screen"), img(src = "https://www.r-project.org/logo/Rlogo.png", width = "200px", height = "200px"), img_intensify() ) server <- function(input, output) { } shinyApp(ui = ui, server = server) }if (interactive()) { ui <- fluidPage( h1("Click on the image to view it in full screen"), img(src = "https://www.r-project.org/logo/Rlogo.png", width = "200px", height = "200px"), img_intensify() ) server <- function(input, output) { } shinyApp(ui = ui, server = server) }
Create an HTML dependency for intense-images.js
intense_dependency()intense_dependency()